/**
 * Generic POST to given path/URL
 */
function post_to_url(path, params, method, targetFrame) {
    method = method || "post"; // Set method to post by default, if not specified.

    // The rest of this code assumes you are not using a library.
    // It can be made less wordy if you use one.
    var form = document.createElement("form");
    form.setAttribute("method", method);
    form.setAttribute("action", path);
    form.setAttribute("target", targetFrame);

    for(var key in params) {
        if(params.hasOwnProperty(key)) {
            var hiddenField = document.createElement("input");
            hiddenField.setAttribute("type", "hidden");
            hiddenField.setAttribute("name", key);
            hiddenField.setAttribute("value", params[key]);

            form.appendChild(hiddenField);
         }
    }

    document.body.appendChild(form);
    form.submit();
    document.body.removeChild(form);
}

/**
 * Shows the Peptide x spectrum match using 
 * the "Xi Spectrum Viewer" (http://sourceforge.net/projects/spectrumviewer/)
 *
 * NB: the specific viewer can be changed later on as well to other web-enabled
 * viewers. The advantage is that
 * such a modification only requires changes in this part.
 *
 * @param peptideSequence: the peptide AA sequence
 * @param peakList: e.g. "138.155548095703 3.09701\n" + "181.162536621094 3.33659";
 * @param precursorZ: the precursor charge, e.g. "2" 
 * @param fragmentMassError: (optional) the fragment mass error tolerance, e.g. "-0.3"(Da) or "60"(ppm)
 *                      (optional, if set to null then script will assume the value should be read from an input field with this name)
 * @param massErrorUnit: "Da" or "ppm"
 *                      (optional, if set to null then script will assume the value should be read from an input field with this name) 
 * @param targetFrame
 *
 */
 var __lastTableRow = null;
function showPeptideSpectrumMatch(peptideSequence, peakList, precursorZ, 
                     fragmentMassError, massErrorUnit, targetFrame, tableRow)
{
	//highlight table row:
	tableRow.style.backgroundColor = "lightgrey";
	if (__lastTableRow != null)
	{
		__lastTableRow.style.backgroundColor = "white";
	}
	__lastTableRow = tableRow;
			
	var params = new Object();
	params.myPeptide  = peptideSequence;
	params.myPeaklist = peakList;
	
	//some defaults needed by "Xi Spectrum Viewer":
	params.myPrecursorZ = precursorZ;
	if (fragmentMassError == null)
		params.myTolerance = document.getElementById("fragmentMassError").value;
	else
		params.myTolerance = fragmentMassError;
	if (massErrorUnit == null)
		params.myToleranceUnit = document.getElementById("massErrorUnit").value;
	else
		params.myToleranceUnit = massErrorUnit;
	params.iontable = "Type	Use	Handedness	Formula\n"+
						"a	N	L	-C -H -O\n"+
						"b	Y	L	-H\n"+
						"c	N	L	N H2\n"+
						"x	N	R	C O -H\n"+
						"y	Y	R	H\n"+
						"z	N	R	-N -H\n";
				
	post_to_url("http://spectrumviewer.org/xisv/index.php", params, "post", targetFrame);
}	
